==> vue-patternfly-0.0.16.tgz: package/README.md <==
# Vue PatternFly

<p align="center">
  <!-- <a href="https://circleci.com/gh/mtorromeo/vue-patternfly">
    <img src="https://circleci.com/gh/mtorromeo/vue-patternfly.svg?style=svg" alt="Build Status" />
  </a>
  <a href="https://coveralls.io/github/mtorromeo/vue-patternfly?branch=master">
    <img src="https://coveralls.io/repos/github/mtorromeo/vue-patternfly/badge.svg?branch=master&style=flat-square" alt="Coverage Status" />
  </a> -->
  <a href="LICENSE">
    <img src="https://img.shields.io/badge/license-MIT-brightgreen.svg?style=flat-square" alt="Software License" />
  </a>
  
  <a href="https://npmjs.org/package/vue-patternfly">
    <img src="https://img.shields.io/npm/v/vue-patternfly.svg?style=flat-square" alt="NPM" />
  </a>
  
  <a href="https://npmjs.org/package/vue-patternfly">
    <img src="https://img.shields.io/npm/dw/vue-patternfly.svg?style=flat-square" alt="Downloads" />
  </a>

  <a href="https://github.com/mtorromeo/vue-patternfly/issues">
    <img src="https://img.shields.io/github/issues/mtorromeo/vue-patternfly.svg?style=flat-square" alt="Issues" />
  </a>
</p>

PatternFly components for Vue.js 2.

**Be warned:** this library is in alpha state and only a small set of components is implemented.

More informations on the project [homepage][link-homepage].

### Installation
```
npm install --save vue-patternfly
```

or

```
yarn add vue-patternfly
```

## Change log

Please see [CHANGELOG](CHANGELOG.md) for more information what has changed recently.

<!-- Tests are not available yet
## Testing

``` bash
$ npm run test
``` -->

## Contributing

Please see [CONTRIBUTING](CONTRIBUTING.md) and [CONDUCT](CONDUCT.md) for details.

## Security

If you discover any security related issues, please email massimiliano.torromeo@gmail.com instead of using the issue tracker.

## Credits

- [Massimiliano Torromeo][link-author]
- [All Contributors][link-contributors]

## License

The MIT License (MIT). Please see [License File](LICENSE.md) for more information.

[link-homepage]: https://mtorromeo.github.io/vue-patternfly
[link-author]: https://github.com/mtorromeo
[link-contributors]: ../../contributors

==> vue-patternfly-0.1.4.tgz: package/README.md <==
# Vue PatternFly

<p align="center">
  <!-- <a href="https://circleci.com/gh/mtorromeo/vue-patternfly">
    <img src="https://circleci.com/gh/mtorromeo/vue-patternfly.svg?style=svg" alt="Build Status" />
  </a>
  <a href="https://coveralls.io/github/mtorromeo/vue-patternfly?branch=master">
    <img src="https://coveralls.io/repos/github/mtorromeo/vue-patternfly/badge.svg?branch=master&style=flat-square" alt="Coverage Status" />
  </a> -->
  <a href="LICENSE">
    <img src="https://img.shields.io/badge/license-MIT-brightgreen.svg?style=flat-square" alt="Software License" />
  </a>

  <a href="https://npmjs.org/package/vue-patternfly">
    <img src="https://img.shields.io/npm/v/vue-patternfly.svg?style=flat-square" alt="NPM" />
  </a>

  <a href="https://npmjs.org/package/vue-patternfly">
    <img src="https://img.shields.io/npm/dw/vue-patternfly.svg?style=flat-square" alt="Downloads" />
  </a>

  <a href="https://github.com/mtorromeo/vue-patternfly/issues">
    <img src="https://img.shields.io/github/issues/mtorromeo/vue-patternfly.svg?style=flat-square" alt="Issues" />
  </a>
</p>

PatternFly components for Vue 2.

More informations on the project [homepage][link-homepage].

### Installation
```
npm install --save vue-patternfly
```

or

```
yarn add vue-patternfly
```

## Change log

Please see [CHANGELOG](CHANGELOG.md) for more information what has changed recently.

<!-- Tests are not available yet
## Testing

``` bash
$ npm run test
``` -->

## Contributing

Please see [CONTRIBUTING](CONTRIBUTING.md) and [CONDUCT](CONDUCT.md) for details.

## Security

If you discover any security related issues, please email massimiliano.torromeo@gmail.com instead of using the issue tracker.

## Credits

- [Massimiliano Torromeo][link-author]
- [All Contributors][link-contributors]

## License

The MIT License (MIT). Please see [License File](LICENSE.md) for more information.

[link-homepage]: https://mtorromeo.github.io/vue-patternfly
[link-author]: https://github.com/mtorromeo
[link-contributors]: ../../contributors
